Cringe Culture
===============

Before even knowing what this package is about, lets change the entire
planet by introducing into coding ...

CRINGE
-------

The changelog is the single most exciting file in a software package.

Authors are influencers. Modern life could actually be tied to
wind direction on a particular day preventing that author from quickly
replying to your issue or approving the PR you submitted.

.. epigraph::

   Pray the stars don't align, wind direction remains favorable, breeze
   soothing, and the author doesn't wolfs out leaving that PR to fester.

   The horror!

   So i'd follow that authors daily musings.

   -- peer pressure or cringe? Board game or t-shirt?

So when an obscure package author says,

.. epigraph::

   Bat boys batarrang is shaped like a flower vase in this particular
   series and episode and scene

   -- some obscure package author you admire

Might want that on a t-shirt. Sounds stupid, for the love of cringe,
you'll come around and embrace stupid. Especially when it seeps into
our culture, muhahahaha (gay not gay right hand pinky to side of
mouth -- Austin powers A spy who shagged me!)

Come to think of it, why isn't stupid the singular focus of our
existance /nosarc? We are literally surrounded by stupids. Oh was i
not supposed to say the quiet part out loud? Go ahead and cancel an
influencial vital package author.

Wait!

Let me get a beer and popcorn first. OK, now, go ahead!

.. epigraph::

   Embrace stupid!

   - an obscure package author giving life advice

What religion is that?

I'm in!
""""""""

The Changelog ``- style:`` category is barely used. It's serious purpose
is to point out the least important forgettable changes that have little or no
impact on the software or that commit.

.. code:: text

   - style: took a shower and feeling refreshed

So, of course, it's the most important changelog category. Cuz
that's where we point out obscure cultural references, of unimportant
objects and minor characters.

- style: End of Dead Snow 2, not 1 cuz that suacked, the van
- style: while the main character is faulking the resurrected corpse,
- style: the window with blood stains. In Dead Snow III, blood stain there?

Did you miss that? The window and the blood stain?

Which leads into the question?

Is the `Star Wars t-shirt and the may the force be with you` scene
suitable for a patch or minor release?

A deep philosophical question, lets clear up any confusion

- ``patch``
  A different cringe reference within the same scene

- ``minor``
  same movie different scene or similar cringe different movie/story

- ``major``
  Different movie, possibly different human language. Possibly
  different genre or culture. Can't understand anything, but
  where can i buy that bra?

  Maybe having to watch only Korean dramas will teach you not to make
  backwards incompatiable breaking changes!

^^ Can't remember; print it on a t-shirt!

SPOILER ALERT! <-- the spoiler alert right before the sudden weird transition to the package docs








In this package, besides in the changelog, the id of snippets,
which jumped staight into without explaining what that is, has to be a
cringe reference.

.. code:: text

   file contents leading up to editable region\n
   # @@@ editable may_the_force_be_with_you_tshirt\n
   abc abc abc\n
   # @@@ end\n
   rest of file contents\n

That's supposed to be a snippet within some configuration file. The
unique id allows for the possibility of multiple snippets within a file.

Don't need to change cringe reference in all snippets, one will suffice.

Scary threat
~~~~~~~~~~~~~

When changing versions, submitting a PR, or raising an issue. Each
would influence the next commit. Without supplying a cringe reference
the author *may* deem this sufficient grounds for refusing the change
or dragging it out to maximize the LOLs.

For example, referencing the absolutely most boring tank, Aquaman. Could
be enough to throw the author into an epileptic fit of rage. Resulting in
unintended consequences and justifiably so!

Unbelievable some people .. tsk

^^ scary threat of impending doom, not the sole realm of pipenv docs

Any Upside?
~~~~~~~~~~~~

If it's a particularly good cringe reference the author *may* prioritize
your request! Never know ... more stupid things have happened.

And if the author disappears, orphaning a package, bombarding the issues
section with enough obscure cringe references can bring back the dead!

Doubt someone will take the effort to dig up John Candy, but after
the later Ghostbusters movies, makes this a distinct possibility. RIP ... unless

^^ cringe README.rst topic transition that comes off as bold and far fetched until IBM's extreme demand for Cobol dinosaurs prompts them to employ quantum garden gnomes to design resurrection chants
